// Copyright 2024 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

use crabby_avif::image::*;
use crabby_avif::utils::y4m;
use crabby_avif::*;

use std::env;
use std::fs::remove_file;
use std::fs::File;
use std::io::BufReader;
use std::io::Read;
use std::process::Command;
use tempfile::NamedTempFile;

// See README.md for instructions on how to set up the dependencies for
// running the conformance tests.

fn get_test_file(filename: &str) -> String {
    let base_path = if cfg!(google3) {
        format!(
            "{}/google3/third_party/crabbyavif/google/test_data/av1-avif",
            env::var("TEST_SRCDIR").expect("TEST_SRCDIR is not defined")
        )
    } else {
        match env::var("CRABBYAVIF_CONFORMANCE_TEST_DATA_DIR") {
            Ok(dir) => format!("{dir}/testFiles"),
            Err(_) => format!(
                "{}/external/av1-avif/testFiles",
                env::var("CARGO_MANIFEST_DIR").expect("CARGO_MANIFEST_DIR is not defined")
            ),
        }
    };
    format!("{base_path}/{filename}")
}

fn get_avifdec() -> String {
    if cfg!(google3) {
        format!(
            "{}/google3/third_party/libavif/avifdec",
            env::var("TEST_SRCDIR").expect("TEST_SRCDIR is not defined")
        )
    } else {
        match env::var("CRABBYAVIF_CONFORMANCE_TEST_AVIFDEC") {
            Ok(avifdec) => avifdec,
            Err(_) => format!(
                "{}/external/libavif/build/avifdec",
                env::var("CARGO_MANIFEST_DIR").expect("CARGO_MANIFEST_DIR is not defined")
            ),
        }
    }
}

#[derive(Clone, Copy)]
struct ExpectedImageInfo<'a> {
    filename: &'a str,
    width: u32,
    height: u32,
    depth: u8,
    yuv_format: PixelFormat,
    alpha_present: bool,
    yuv_range: YuvRange,
    color_primaries: u16,
    transfer_characteristics: u16,
    matrix_coefficients: u16,
    color_obu_size: usize,
    alpha_obu_size: usize,
}

fn verify_info(expected_info: &ExpectedImageInfo, image: &Image) {
    assert_eq!(image.width, expected_info.width);
    assert_eq!(image.height, expected_info.height);
    assert_eq!(image.depth, expected_info.depth);
    assert_eq!(image.yuv_format, expected_info.yuv_format);
    assert_eq!(image.alpha_present, expected_info.alpha_present);
    assert_eq!(image.yuv_range, expected_info.yuv_range);
    assert_eq!(image.color_primaries, expected_info.color_primaries.into());
    assert_eq!(
        image.transfer_characteristics,
        expected_info.transfer_characteristics.into()
    );
    assert_eq!(
        image.matrix_coefficients,
        expected_info.matrix_coefficients.into()
    );
}

fn get_tempfile() -> String {
    let file = NamedTempFile::new().expect("unable to open tempfile");
    let path = file.into_temp_path();
    let filename = String::from(path.to_str().unwrap());
    let _ = path.close();
    filename
}

fn write_y4m(image: &Image) -> String {
    let filename = get_tempfile();
    let mut y4m = y4m::Y4MWriter::create(&filename);
    assert!(y4m.write_frame(image));
    filename
}

fn run_avifdec(filename: &String) -> String {
    let mut outfile = get_tempfile();
    outfile.push_str(".y4m");
    let avifdec = Command::new(get_avifdec())
        .arg("--no-strict")
        .arg("--jobs")
        .arg("8")
        .arg(filename)
        .arg(&outfile)
        .output()
        .unwrap();
    assert!(avifdec.status.success());
    outfile
}

fn compare_files(file1: &String, file2: &String) -> bool {
    let f1 = File::open(file1).unwrap();
    let f2 = File::open(file2).unwrap();
    if f1.metadata().unwrap().len() != f2.metadata().unwrap().len() {
        return false;
    }
    let f1 = BufReader::new(f1);
    let f2 = BufReader::new(f2);
    for (byte1, byte2) in f1.bytes().zip(f2.bytes()) {
        if byte1.unwrap() != byte2.unwrap() {
            return false;
        }
    }
    true
}

#[test_case::test_matrix(0usize..172)]
fn test_conformance(index: usize) {
    let expected_info = &EXPECTED_INFOS[index];
    let filename = get_test_file(expected_info.filename);
    let mut decoder = decoder::Decoder::default();
    decoder.settings.strictness = decoder::Strictness::None;
    let _ = decoder.set_io_file(&filename).expect("Failed to set IO");
    let res = decoder.parse();
    assert!(res.is_ok());
    assert_eq!(
        expected_info.color_obu_size,
        decoder.io_stats().color_obu_size
    );
    assert_eq!(
        expected_info.alpha_obu_size,
        decoder.io_stats().alpha_obu_size
    );
    let image = decoder.image().expect("image was none");
    verify_info(expected_info, &image);
    let res = decoder.next_image();
    assert!(res.is_ok());
    let image = decoder.image().expect("image was none");

    // Link-U 422 files have wrong subsampling in the Avif header(decoded one
    // is right).
    if !filename.contains("Link-U") || !filename.contains("yuv422") {
        verify_info(expected_info, &image);
    }

    // Write y4m.
    let y4m_file = write_y4m(image);
    // Write y4m by invoking avifdec.
    let gold_y4m_file = run_avifdec(&filename);
    // Compare.
    assert!(compare_files(&y4m_file, &gold_y4m_file));
    let _ = remove_file(y4m_file);
    let _ = remove_file(gold_y4m_file);
}

// If more files are added to this array, update the call to generate_tests macro below.
const EXPECTED_INFOS: [ExpectedImageInfo; 172] = [
    // index: 0
    ExpectedImageInfo {
        filename: "Apple/edge_case_testing/non_compliant/truncated_elementary_stream.avif",
        width: 1024,
        height: 768,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 122336,
        alpha_obu_size: 0,
    },
    // index: 1
    ExpectedImageInfo {
        filename: "Apple/edge_case_testing/unknown_properties/free_property.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 2063701,
        alpha_obu_size: 0,
    },
    // index: 2
    ExpectedImageInfo {
        filename: "Apple/edge_case_testing/unknown_properties/unknown_nonessential_property.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 2063701,
        alpha_obu_size: 0,
    },
    // index: 3
    ExpectedImageInfo {
        filename: "Apple/multilayer_examples/animals_00_multilayer_a1lx.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 1999503,
        alpha_obu_size: 0,
    },
    // index: 4
    ExpectedImageInfo {
        filename: "Apple/multilayer_examples/animals_00_multilayer_a1op.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 1999503,
        alpha_obu_size: 0,
    },
    // index: 5
    ExpectedImageInfo {
        filename: "Apple/multilayer_examples/animals_00_multilayer_a1op_lsel.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 1999503,
        alpha_obu_size: 0,
    },
    // index: 6
    ExpectedImageInfo {
        filename: "Apple/multilayer_examples/animals_00_multilayer_grid_a1lx.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 2306164,
        alpha_obu_size: 0,
    },
    // index: 7
    ExpectedImageInfo {
        filename: "Apple/multilayer_examples/animals_00_multilayer_grid_lsel.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 2306164,
        alpha_obu_size: 0,
    },
    // index: 8
    ExpectedImageInfo {
        filename: "Apple/multilayer_examples/animals_00_multilayer_lsel.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 1999503,
        alpha_obu_size: 0,
    },
    // index: 9
    ExpectedImageInfo {
        filename: "Apple/multilayer_examples/animals_00_singlelayer.avif",
        width: 2048,
        height: 1536,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 12,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 2063701,
        alpha_obu_size: 0,
    },
    // index: 10
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.avif",
        width: 1204,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 64098,
        alpha_obu_size: 0,
    },
    // index: 11
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.monochrome.avif",
        width: 1204,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 56116,
        alpha_obu_size: 0,
    },
    // index: 12
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.monochrome.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55174,
        alpha_obu_size: 0,
    },
    // index: 13
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.monochrome.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55254,
        alpha_obu_size: 0,
    },
    // index: 14
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.monochrome.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54589,
        alpha_obu_size: 0,
    },
    // index: 15
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 63262,
        alpha_obu_size: 0,
    },
    // index: 16
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 63442,
        alpha_obu_size: 0,
    },
    // index: 17
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.10bpc.yuv420.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 62619,
        alpha_obu_size: 0,
    },
    // index: 18
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.avif",
        width: 1204,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 63157,
        alpha_obu_size: 0,
    },
    // index: 19
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.monochrome.avif",
        width: 1204,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55329,
        alpha_obu_size: 0,
    },
    // index: 20
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.monochrome.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54376,
        alpha_obu_size: 0,
    },
    // index: 21
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.monochrome.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54460,
        alpha_obu_size: 0,
    },
    // index: 22
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.monochrome.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 53836,
        alpha_obu_size: 0,
    },
    // index: 23
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 62451,
        alpha_obu_size: 0,
    },
    // index: 24
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 62535,
        alpha_obu_size: 0,
    },
    // index: 25
    ExpectedImageInfo {
        filename: "Link-U/fox.profile0.8bpc.yuv420.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 61950,
        alpha_obu_size: 0,
    },
    // index: 26
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.10bpc.yuv444.avif",
        width: 1204,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 74745,
        alpha_obu_size: 0,
    },
    // index: 27
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.10bpc.yuv444.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 73212,
        alpha_obu_size: 0,
    },
    // index: 28
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.10bpc.yuv444.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 73266,
        alpha_obu_size: 0,
    },
    // index: 29
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.10bpc.yuv444.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 72379,
        alpha_obu_size: 0,
    },
    // index: 30
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.8bpc.yuv444.avif",
        width: 1204,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 73902,
        alpha_obu_size: 0,
    },
    // index: 31
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.8bpc.yuv444.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 72478,
        alpha_obu_size: 0,
    },
    // index: 32
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.8bpc.yuv444.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 72769,
        alpha_obu_size: 0,
    },
    // index: 33
    ExpectedImageInfo {
        filename: "Link-U/fox.profile1.8bpc.yuv444.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 71795,
        alpha_obu_size: 0,
    },
    // index: 34
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.avif",
        width: 1204,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 68524,
        alpha_obu_size: 0,
    },
    // index: 35
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.monochrome.avif",
        width: 1204,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 56116,
        alpha_obu_size: 0,
    },
    // index: 36
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.monochrome.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55174,
        alpha_obu_size: 0,
    },
    // index: 37
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.monochrome.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55254,
        alpha_obu_size: 0,
    },
    // index: 38
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.monochrome.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54589,
        alpha_obu_size: 0,
    },
    // index: 39
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 67602,
        alpha_obu_size: 0,
    },
    // index: 40
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 67803,
        alpha_obu_size: 0,
    },
    // index: 41
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.10bpc.yuv422.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 66794,
        alpha_obu_size: 0,
    },
    // index: 42
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.avif",
        width: 1204,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 64688,
        alpha_obu_size: 0,
    },
    // index: 43
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.monochrome.avif",
        width: 1204,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 56651,
        alpha_obu_size: 0,
    },
    // index: 44
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.monochrome.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55561,
        alpha_obu_size: 0,
    },
    // index: 45
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.monochrome.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55679,
        alpha_obu_size: 0,
    },
    // index: 46
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.monochrome.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54936,
        alpha_obu_size: 0,
    },
    // index: 47
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 63714,
        alpha_obu_size: 0,
    },
    // index: 48
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 63791,
        alpha_obu_size: 0,
    },
    // index: 49
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv420.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 63145,
        alpha_obu_size: 0,
    },
    // index: 50
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.avif",
        width: 1204,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 69054,
        alpha_obu_size: 0,
    },
    // index: 51
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.monochrome.avif",
        width: 1204,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 56651,
        alpha_obu_size: 0,
    },
    // index: 52
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.monochrome.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55561,
        alpha_obu_size: 0,
    },
    // index: 53
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.monochrome.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55679,
        alpha_obu_size: 0,
    },
    // index: 54
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.monochrome.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54936,
        alpha_obu_size: 0,
    },
    // index: 55
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 67792,
        alpha_obu_size: 0,
    },
    // index: 56
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 68051,
        alpha_obu_size: 0,
    },
    // index: 57
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv422.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 67328,
        alpha_obu_size: 0,
    },
    // index: 58
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.avif",
        width: 1204,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 75004,
        alpha_obu_size: 0,
    },
    // index: 59
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.monochrome.avif",
        width: 1204,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 56651,
        alpha_obu_size: 0,
    },
    // index: 60
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.monochrome.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55561,
        alpha_obu_size: 0,
    },
    // index: 61
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.monochrome.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55679,
        alpha_obu_size: 0,
    },
    // index: 62
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.monochrome.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54936,
        alpha_obu_size: 0,
    },
    // index: 63
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 73694,
        alpha_obu_size: 0,
    },
    // index: 64
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 73720,
        alpha_obu_size: 0,
    },
    // index: 65
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.12bpc.yuv444.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 72725,
        alpha_obu_size: 0,
    },
    // index: 66
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.avif",
        width: 1204,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 67538,
        alpha_obu_size: 0,
    },
    // index: 67
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.monochrome.avif",
        width: 1204,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 55329,
        alpha_obu_size: 0,
    },
    // index: 68
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.monochrome.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54376,
        alpha_obu_size: 0,
    },
    // index: 69
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.monochrome.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 54460,
        alpha_obu_size: 0,
    },
    // index: 70
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.monochrome.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 53836,
        alpha_obu_size: 0,
    },
    // index: 71
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.odd-height.avif",
        width: 1204,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 66814,
        alpha_obu_size: 0,
    },
    // index: 72
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.odd-width.avif",
        width: 1203,
        height: 800,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 66974,
        alpha_obu_size: 0,
    },
    // index: 73
    ExpectedImageInfo {
        filename: "Link-U/fox.profile2.8bpc.yuv422.odd-width.odd-height.avif",
        width: 1203,
        height: 799,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 66154,
        alpha_obu_size: 0,
    },
    // index: 74
    ExpectedImageInfo {
        filename: "Link-U/hato.profile0.10bpc.yuv420.monochrome.no-cdef.no-restoration.avif",
        width: 3082,
        height: 2048,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 178883,
        alpha_obu_size: 0,
    },
    // index: 75
    ExpectedImageInfo {
        filename: "Link-U/hato.profile0.10bpc.yuv420.no-cdef.no-restoration.avif",
        width: 3082,
        height: 2048,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 208271,
        alpha_obu_size: 0,
    },
    // index: 76
    ExpectedImageInfo {
        filename: "Link-U/hato.profile0.8bpc.yuv420.monochrome.no-cdef.avif",
        width: 3082,
        height: 2048,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 177474,
        alpha_obu_size: 0,
    },
    // index: 77
    ExpectedImageInfo {
        filename: "Link-U/hato.profile0.8bpc.yuv420.no-cdef.avif",
        width: 3082,
        height: 2048,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 207414,
        alpha_obu_size: 0,
    },
    // index: 78
    ExpectedImageInfo {
        filename: "Link-U/hato.profile2.10bpc.yuv422.monochrome.no-cdef.no-restoration.avif",
        width: 3082,
        height: 2048,
        depth: 10,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 178883,
        alpha_obu_size: 0,
    },
    // index: 79
    ExpectedImageInfo {
        filename: "Link-U/hato.profile2.10bpc.yuv422.no-cdef.no-restoration.avif",
        width: 3082,
        height: 2048,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 225894,
        alpha_obu_size: 0,
    },
    // index: 80
    ExpectedImageInfo {
        filename: "Link-U/hato.profile2.12bpc.yuv422.monochrome.avif",
        width: 3082,
        height: 2048,
        depth: 12,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 2,
        matrix_coefficients: 9,
        color_obu_size: 231531,
        alpha_obu_size: 0,
    },
    // index: 81
    ExpectedImageInfo {
        filename: "Link-U/hato.profile2.12bpc.yuv422.monochrome.no-cdef.no-restoration.avif",
        width: 3082,
        height: 2048,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 226731,
        alpha_obu_size: 0,
    },
    // index: 82
    ExpectedImageInfo {
        filename: "Link-U/hato.profile2.12bpc.yuv422.no-cdef.no-restoration.avif",
        width: 3082,
        height: 2048,
        depth: 12,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 226731,
        alpha_obu_size: 0,
    },
    // index: 83
    ExpectedImageInfo {
        filename: "Link-U/hato.profile2.8bpc.yuv422.monochrome.no-cdef.avif",
        width: 3082,
        height: 2048,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 177474,
        alpha_obu_size: 0,
    },
    // index: 84
    ExpectedImageInfo {
        filename: "Link-U/hato.profile2.8bpc.yuv422.no-cdef.avif",
        width: 3082,
        height: 2048,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 225881,
        alpha_obu_size: 0,
    },
    // index: 85
    ExpectedImageInfo {
        filename: "Link-U/kimono.avif",
        width: 722,
        height: 1024,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 85120,
        alpha_obu_size: 0,
    },
    // index: 86
    ExpectedImageInfo {
        filename: "Link-U/kimono.crop.avif",
        width: 722,
        height: 1024,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 85120,
        alpha_obu_size: 0,
    },
    // index: 87
    ExpectedImageInfo {
        filename: "Link-U/kimono.mirror-horizontal.avif",
        width: 722,
        height: 1024,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 84661,
        alpha_obu_size: 0,
    },
    // index: 88
    ExpectedImageInfo {
        filename: "Link-U/kimono.mirror-vertical.avif",
        width: 722,
        height: 1024,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 84297,
        alpha_obu_size: 0,
    },
    // index: 89
    ExpectedImageInfo {
        filename: "Link-U/kimono.mirror-vertical.rotate270.avif",
        width: 1024,
        height: 722,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 85184,
        alpha_obu_size: 0,
    },
    // index: 90
    ExpectedImageInfo {
        filename: "Link-U/kimono.mirror-vertical.rotate270.crop.avif",
        width: 1024,
        height: 722,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 85184,
        alpha_obu_size: 0,
    },
    // index: 91
    ExpectedImageInfo {
        filename: "Link-U/kimono.rotate270.avif",
        width: 1024,
        height: 722,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 84551,
        alpha_obu_size: 0,
    },
    // index: 92
    ExpectedImageInfo {
        filename: "Link-U/kimono.rotate90.avif",
        width: 1024,
        height: 722,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 9,
        color_obu_size: 84502,
        alpha_obu_size: 0,
    },
    // index: 93
    ExpectedImageInfo {
        filename: "Microsoft/Chimera_10bit_cropped_to_1920x1008.avif",
        width: 1920,
        height: 1080,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 95279,
        alpha_obu_size: 0,
    },
    // index: 94
    ExpectedImageInfo {
        filename: "Microsoft/Chimera_10bit_cropped_to_1920x1008_with_HDR_metadata.avif",
        width: 1920,
        height: 1080,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 10,
        color_obu_size: 95279,
        alpha_obu_size: 0,
    },
    // index: 95
    ExpectedImageInfo {
        filename: "Microsoft/Chimera_8bit_cropped_480x256.avif",
        width: 480,
        height: 270,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 37860,
        alpha_obu_size: 0,
    },
    // index: 96
    ExpectedImageInfo {
        filename: "Microsoft/Irvine_CA.avif",
        width: 480,
        height: 640,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 27601,
        alpha_obu_size: 0,
    },
    // index: 97
    ExpectedImageInfo {
        filename: "Microsoft/Mexico.avif",
        width: 1920,
        height: 1080,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 218726,
        alpha_obu_size: 0,
    },
    // index: 98
    ExpectedImageInfo {
        filename: "Microsoft/Mexico_YUV444.avif",
        width: 960,
        height: 540,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 158350,
        alpha_obu_size: 0,
    },
    // index: 99
    ExpectedImageInfo {
        filename: "Microsoft/Monochrome.avif",
        width: 1280,
        height: 720,
        depth: 8,
        yuv_format: PixelFormat::Yuv400,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 1,
        matrix_coefficients: 1,
        color_obu_size: 6979,
        alpha_obu_size: 0,
    },
    // index: 100
    ExpectedImageInfo {
        filename: "Microsoft/Ronda_rotate90.avif",
        width: 1920,
        height: 1080,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 95912,
        alpha_obu_size: 0,
    },
    // index: 101
    ExpectedImageInfo {
        filename: "Microsoft/Summer_Nature_4k.avif",
        width: 3840,
        height: 2160,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 279919,
        alpha_obu_size: 0,
    },
    // index: 102
    ExpectedImageInfo {
        filename: "Microsoft/Summer_in_Tomsk_720p_5x4_grid.avif",
        width: 6400,
        height: 2880,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 1963366,
        alpha_obu_size: 0,
    },
    // index: 103
    ExpectedImageInfo {
        filename: "Microsoft/Tomsk_with_thumbnails.avif",
        width: 1280,
        height: 720,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 7618,
        alpha_obu_size: 0,
    },
    // index: 104
    ExpectedImageInfo {
        filename: "Microsoft/bbb_4k.avif",
        width: 3840,
        height: 2160,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 30980,
        alpha_obu_size: 0,
    },
    // index: 105
    ExpectedImageInfo {
        filename: "Microsoft/bbb_alpha_inverted.avif",
        width: 3840,
        height: 2160,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: true,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 4508,
        alpha_obu_size: 3202,
    },
    // index: 106
    ExpectedImageInfo {
        filename: "Microsoft/kids_720p.avif",
        width: 1280,
        height: 720,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 57105,
        alpha_obu_size: 0,
    },
    // index: 107
    ExpectedImageInfo {
        filename: "Microsoft/reduced_still_picture_header.avif",
        width: 1280,
        height: 720,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 7618,
        alpha_obu_size: 0,
    },
    // index: 108
    ExpectedImageInfo {
        filename: "Microsoft/still_picture.avif",
        width: 1280,
        height: 720,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 7624,
        alpha_obu_size: 0,
    },
    // index: 109
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01000_cicp9-16-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 0,
        color_obu_size: 2030306,
        alpha_obu_size: 0,
    },
    // index: 110
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01000_cicp9-16-9_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 92239,
        alpha_obu_size: 0,
    },
    // index: 111
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01000_cicp9-16-9_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 32939,
        alpha_obu_size: 0,
    },
    // index: 112
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01000_cicp9-16-9_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 9547,
        alpha_obu_size: 0,
    },
    // index: 113
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01000_cicp9-16-9_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 129471,
        alpha_obu_size: 0,
    },
    // index: 114
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01000_cicp9-16-9_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 45646,
        alpha_obu_size: 0,
    },
    // index: 115
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01000_cicp9-16-9_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 12595,
        alpha_obu_size: 0,
    },
    // index: 116
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01650_cicp9-16-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 0,
        color_obu_size: 2865083,
        alpha_obu_size: 0,
    },
    // index: 117
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01650_cicp9-16-9_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 260689,
        alpha_obu_size: 0,
    },
    // index: 118
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01650_cicp9-16-9_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 130393,
        alpha_obu_size: 0,
    },
    // index: 119
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01650_cicp9-16-9_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 29579,
        alpha_obu_size: 0,
    },
    // index: 120
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01650_cicp9-16-9_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 372069,
        alpha_obu_size: 0,
    },
    // index: 121
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01650_cicp9-16-9_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 173936,
        alpha_obu_size: 0,
    },
    // index: 122
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos01650_cicp9-16-9_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 39535,
        alpha_obu_size: 0,
    },
    // index: 123
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos07296_cicp9-16-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 0,
        color_obu_size: 2164296,
        alpha_obu_size: 0,
    },
    // index: 124
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos07296_cicp9-16-9_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 124229,
        alpha_obu_size: 0,
    },
    // index: 125
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos07296_cicp9-16-9_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 40359,
        alpha_obu_size: 0,
    },
    // index: 126
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos07296_cicp9-16-9_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 7874,
        alpha_obu_size: 0,
    },
    // index: 127
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos07296_cicp9-16-9_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 204393,
        alpha_obu_size: 0,
    },
    // index: 128
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos07296_cicp9-16-9_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 61973,
        alpha_obu_size: 0,
    },
    // index: 129
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos07296_cicp9-16-9_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 11224,
        alpha_obu_size: 0,
    },
    // index: 130
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos12920_cicp9-16-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 0,
        color_obu_size: 3055111,
        alpha_obu_size: 0,
    },
    // index: 131
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos12920_cicp9-16-9_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 95933,
        alpha_obu_size: 0,
    },
    // index: 132
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos12920_cicp9-16-9_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 47119,
        alpha_obu_size: 0,
    },
    // index: 133
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos12920_cicp9-16-9_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 16529,
        alpha_obu_size: 0,
    },
    // index: 134
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos12920_cicp9-16-9_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 143650,
        alpha_obu_size: 0,
    },
    // index: 135
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos12920_cicp9-16-9_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 66240,
        alpha_obu_size: 0,
    },
    // index: 136
    ExpectedImageInfo {
        filename: "Netflix/avif/hdr_cosmos12920_cicp9-16-9_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 10,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 9,
        transfer_characteristics: 16,
        matrix_coefficients: 9,
        color_obu_size: 23455,
        alpha_obu_size: 0,
    },
    // index: 137
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01000_cicp1-13-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 0,
        color_obu_size: 1323382,
        alpha_obu_size: 0,
    },
    // index: 138
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01000_cicp1-13-6_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 91887,
        alpha_obu_size: 0,
    },
    // index: 139
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01000_cicp1-13-6_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 44338,
        alpha_obu_size: 0,
    },
    // index: 140
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01000_cicp1-13-6_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 12204,
        alpha_obu_size: 0,
    },
    // index: 141
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01000_cicp1-13-6_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 129688,
        alpha_obu_size: 0,
    },
    // index: 142
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01000_cicp1-13-6_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 61926,
        alpha_obu_size: 0,
    },
    // index: 143
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01000_cicp1-13-6_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 16744,
        alpha_obu_size: 0,
    },
    // index: 144
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01650_cicp1-13-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 0,
        color_obu_size: 1734421,
        alpha_obu_size: 0,
    },
    // index: 145
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01650_cicp1-13-6_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 246525,
        alpha_obu_size: 0,
    },
    // index: 146
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01650_cicp1-13-6_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 128922,
        alpha_obu_size: 0,
    },
    // index: 147
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01650_cicp1-13-6_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 39209,
        alpha_obu_size: 0,
    },
    // index: 148
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01650_cicp1-13-6_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 370809,
        alpha_obu_size: 0,
    },
    // index: 149
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01650_cicp1-13-6_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 187912,
        alpha_obu_size: 0,
    },
    // index: 150
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos01650_cicp1-13-6_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 53041,
        alpha_obu_size: 0,
    },
    // index: 151
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos07296_cicp1-13-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 0,
        color_obu_size: 1389248,
        alpha_obu_size: 0,
    },
    // index: 152
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos07296_cicp1-13-6_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 131503,
        alpha_obu_size: 0,
    },
    // index: 153
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos07296_cicp1-13-6_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 62338,
        alpha_obu_size: 0,
    },
    // index: 154
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos07296_cicp1-13-6_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 15027,
        alpha_obu_size: 0,
    },
    // index: 155
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos07296_cicp1-13-6_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 282438,
        alpha_obu_size: 0,
    },
    // index: 156
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos07296_cicp1-13-6_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 134294,
        alpha_obu_size: 0,
    },
    // index: 157
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos07296_cicp1-13-6_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 24570,
        alpha_obu_size: 0,
    },
    // index: 158
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos12920_cicp1-13-0_lossless.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 0,
        color_obu_size: 2061853,
        alpha_obu_size: 0,
    },
    // index: 159
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos12920_cicp1-13-6_yuv420_limited_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 153575,
        alpha_obu_size: 0,
    },
    // index: 160
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos12920_cicp1-13-6_yuv420_limited_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 75234,
        alpha_obu_size: 0,
    },
    // index: 161
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos12920_cicp1-13-6_yuv420_limited_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 27418,
        alpha_obu_size: 0,
    },
    // index: 162
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos12920_cicp1-13-6_yuv444_full_qp10.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 285667,
        alpha_obu_size: 0,
    },
    // index: 163
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos12920_cicp1-13-6_yuv444_full_qp20.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 119878,
        alpha_obu_size: 0,
    },
    // index: 164
    ExpectedImageInfo {
        filename: "Netflix/avif/sdr_cosmos12920_cicp1-13-6_yuv444_full_qp40.avif",
        width: 2048,
        height: 858,
        depth: 8,
        yuv_format: PixelFormat::Yuv444,
        alpha_present: false,
        yuv_range: YuvRange::Full,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 6,
        color_obu_size: 41906,
        alpha_obu_size: 0,
    },
    // index: 165
    ExpectedImageInfo {
        filename: "Netflix/avis/Chimera-AV1-10bit-480x270.avif",
        width: 480,
        height: 270,
        depth: 10,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 2,
        transfer_characteristics: 2,
        matrix_coefficients: 2,
        color_obu_size: 142540,
        alpha_obu_size: 0,
    },
    // index: 166
    ExpectedImageInfo {
        filename: "Netflix/avis/alpha_video.avif",
        width: 640,
        height: 480,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: true,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 3487,
        alpha_obu_size: 4642,
    },
    // index: 167
    ExpectedImageInfo {
        filename: "Xiph/abandoned_filmgrain.avif",
        width: 1404,
        height: 936,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 141119,
        alpha_obu_size: 0,
    },
    // index: 168
    ExpectedImageInfo {
        filename: "Xiph/fruits_2layer_thumbsize.avif",
        width: 1296,
        height: 864,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 35097,
        alpha_obu_size: 0,
    },
    // index: 169
    ExpectedImageInfo {
        filename: "Xiph/quebec_3layer_op2.avif",
        width: 360,
        height: 182,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 86246,
        alpha_obu_size: 0,
    },
    // index: 170
    ExpectedImageInfo {
        filename: "Xiph/tiger_3layer_1res.avif",
        width: 1216,
        height: 832,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 70551,
        alpha_obu_size: 0,
    },
    // index: 171
    ExpectedImageInfo {
        filename: "Xiph/tiger_3layer_3res.avif",
        width: 1216,
        height: 832,
        depth: 8,
        yuv_format: PixelFormat::Yuv420,
        alpha_present: false,
        yuv_range: YuvRange::Limited,
        color_primaries: 1,
        transfer_characteristics: 13,
        matrix_coefficients: 1,
        color_obu_size: 64582,
        alpha_obu_size: 0,
    },
];
